@@ -12,6 +12,7 @@
 #include "Transaction/TransactionModel.h"
 
 #include <AppStreamQt/release.h>
+#include <AppStreamQt/systeminfo.h>
 #include <AppStreamQt/utils.h>
 #include <KLocalizedString>
 #include <appstream/AppStreamIntegration.h>
@@ -310,7 +311,7 @@ void RpmOstreeBackend::lookForNextMajorVersion()
 
     // Get the DistroComponentId. For Fedora Kinoite, we follow Fedora's
     // release schedule so we don't have our own ID.
-    QString distroId = AppStream::Utils::currentDistroComponentId();
+    QString distroId = AppStream::SystemInfo::currentDistroComponentId();
     if (distroId == QLatin1String("org.fedoraproject.kinoite.fedora")) {
         distroId = QStringLiteral("org.fedoraproject.fedora");
     }
@@ -325,11 +326,7 @@ void RpmOstreeBackend::lookForNextMajorVersion()
     QString currentVersion = AppStreamIntegration::global()->osRelease()->versionId();
     QString nextVersion;
     for (const AppStream::Component &dc : distroComponents) {
-#if ASQ_CHECK_VERSION(1, 0, 0)
         const auto releases = dc.releasesPlain().entries();
-#else
-        const auto releases = dc.releases();
-#endif
         for (const auto &r : releases) {
             // Only look at stable releases unless development mode is enabled
             if ((r.kind() != AppStream::Release::KindStable) && !m_developmentEnabled) {
@@ -395,23 +392,25 @@ void RpmOstreeBackend::foundNewMajorVersion(const QString &newMajorVersion)
         return;
     }
 
+    const QString newDistroVersionText = m_currentlyBootedDeployment->packageName() + QStringLiteral(" ") + newMajorVersion;
+
     QString info;
     // Message to display when:
     // - A new major version is available
     // - An update to the current version is available or pending a reboot
-    info = i18n(
-        "<b>A new major version of %1 has been released!</b>\n"
-        "To be able to update to this new version, make sure to apply all pending updates and reboot your system.",
-        m_currentlyBootedDeployment->packageName());
-    m_rebootBeforeRebaseMessage = QSharedPointer<InlineMessage>::create(InlineMessage::Positive, QStringLiteral("application-x-rpm"), info);
+    info = i18nc("@info:status %1 is a new major version of the user's distro",
+                 "<b>%1 is now available.</b>\n"
+                 "To be able to upgrade to this new version, first apply all available updates, and then restart the system.",
+                 newDistroVersionText);
+    m_rebootBeforeRebaseMessage = QSharedPointer<InlineMessage>::create(InlineMessage::Positive, QStringLiteral("system-software-update"), info);
 
     // Message to display when:
     // - A new major version is available
     // - No update to the current version are available or pending a reboot
-    DiscoverAction *rebase = new DiscoverAction(i18n("Upgrade to %1 %2", m_currentlyBootedDeployment->packageName(), newMajorVersion), this);
-    connect(rebase, &DiscoverAction::triggered, this, &RpmOstreeBackend::rebaseToNewVersion);
-    info = i18n("<b>A new major version has been released!</b>");
-    m_rebaseAvailableMessage = QSharedPointer<InlineMessage>::create(InlineMessage::Positive, QStringLiteral("application-x-rpm"), info, rebase);
+    DiscoverAction *majorUpgrade = new DiscoverAction(QStringLiteral("system-upgrade-symbolic"), i18nc("@action: button", "Begin Upgrade…"), this);
+    connect(majorUpgrade, &DiscoverAction::triggered, this, &RpmOstreeBackend::rebaseToNewVersion);
+    info = i18nc("@info:status %1 is a new major version of the user's distro", "%1 is now available.", newDistroVersionText);
+    m_rebaseAvailableMessage = QSharedPointer<InlineMessage>::create(InlineMessage::Positive, QStringLiteral("system-software-update"), info, majorUpgrade);
 
     // Look for an existing deployment for the new major version
     QVectorIterator<RpmOstreeResource *> iterator(m_resources);
@@ -487,7 +486,7 @@ ResultsStream *RpmOstreeBackend::search(const AbstractResourcesBackend::Filters
     // Trim whitespace from beginning and end of the string entered in the search field.
     QString keyword = filter.search.trimmed();
 
-    QVector<AbstractResource *> res;
+    QVector<StreamResult> res;
     for (RpmOstreeResource *r : m_resources) {
         // Skip if the state does not match the filter
         if (r->state() < filter.state) {
