@@ -7,6 +7,7 @@
 #include "AbstractResourcesBackend.h"
 #include "Category/Category.h"
 #include "libdiscover_debug.h"
+#include "utils.h"
 #include <KLocalizedString>
 #include <QHash>
 #include <QMetaObject>
@@ -36,10 +37,12 @@ QDebug operator<<(QDebug debug, const AbstractResourcesBackend::Filters &filters
     return debug;
 }
 
-ResultsStream::ResultsStream(const QString &objectName, const QVector<AbstractResource *> &resources)
+ResultsStream::ResultsStream(const QString &objectName, const QVector<StreamResult> &resources)
     : ResultsStream(objectName)
 {
-    Q_ASSERT(!resources.contains(nullptr));
+    Q_ASSERT(!kContains(resources, [](const StreamResult &res) {
+        return res.resource == nullptr;
+    }));
     QTimer::singleShot(0, this, [resources, this]() {
         if (!resources.isEmpty())
             Q_EMIT resourcesFound(resources);
@@ -71,7 +74,7 @@ AbstractResourcesBackend::AbstractResourcesBackend(QObject *parent)
     fetchingChangedTimer->setInterval(3000);
     fetchingChangedTimer->setSingleShot(true);
     connect(fetchingChangedTimer, &QTimer::timeout, this, [this] {
-        qDebug() << "took really long to fetch" << this;
+        qCDebug(LIBDISCOVER_LOG) << "took really long to fetch" << this;
     });
 
     connect(this, &AbstractResourcesBackend::fetchingChanged, this, [this, fetchingChangedTimer] {
@@ -138,9 +141,19 @@ void AbstractResourcesBackend::Filters::filterJustInCase(QVector<AbstractResourc
     }
 }
 
-QStringList AbstractResourcesBackend::extends() const
+void AbstractResourcesBackend::Filters::filterJustInCase(QVector<StreamResult> &input) const
 {
-    return {};
+    for (auto it = input.begin(); it != input.end();) {
+        if (shouldFilter(it->resource))
+            ++it;
+        else
+            it = input.erase(it);
+    }
+}
+
+bool AbstractResourcesBackend::extends(const QString & /*id*/) const
+{
+    return false;
 }
 
 int AbstractResourcesBackend::fetchingUpdatesProgress() const
@@ -148,6 +161,11 @@ int AbstractResourcesBackend::fetchingUpdatesProgress() const
     return isFetching() ? 42 : 100;
 }
 
+uint AbstractResourcesBackend::fetchingUpdatesProgressWeight() const
+{
+    return 1;
+}
+
 InlineMessage *AbstractResourcesBackend::explainDysfunction() const
 {
     return new InlineMessage(InlineMessage::Error, QStringLiteral("network-disconnect"), i18n("Please verify Internet connectivity"));
